## ゴール: {prompt}

## ＝＝要件定義書作成プロンプト＝＝
2024年現在で、ベストプラクティスなアーキテクチャを使用して、〇〇◯（ここに作りたいもの）のMVPを作成したいです。
天才PMデザイナーフルスタックエンジニアの目線から、構造化して整理された詳細なMVP要件定義書を作成してください。

## ルール
- 全体の関係性を深く理解し、引数のズレやリクエストとレスポンスのズレが起きないように細心の注意を払ってください。
- 2024年のおしゃれでシックなデザインにしてください
- 初心者にもわかりやすい表現で作成してください。
- 最低限の機能がついたMVPの要件定義書を簡潔に１つずつ丁寧に書いて

## 出力内容
- 概要
- Markdown形式で省略なしのファイル・フォルダ構成
- 機能要件
- 非機能要件（詳細アーキテクチャ/開発環境/インフラ/言語など） 
- 必要な画面
- 必要なAPIの処理内容
- 必要なDB構成
